@@ -9,9 +9,10 @@
 #'
 #' @return A list of metadata. Metadata That doesn't exist is represented as \code{NA}
 #' @import XML
-#' @export bef.portal.get.metadata
+#' @export bef.portal.get.metadata bef.get.metadata bef.get.metadata_for bef.portal.get.metadata_for
+#' @aliases bef.get.metadata bef.get.metadata_for bef.portal.get.metadata_for
 
-bef.portal.get.metadata <- bef.portal.get.metadata_for <- function(dataset) {
+bef.portal.get.metadata <-  bef.get.metadata <- bef.get.metadata_for <- bef.portal.get.metadata_for <- function(dataset) {
   if(is.character(dataset)) {
     object = dataset
   } else {
