@@ -8,15 +8,12 @@
 #'  \code{bef.getMetadata} \tab \code{\link{bef.portal.get.metadata}} \cr
 #'  \code{bef.getKeywords} \tab \code{\link{bef.portal.get.keywords}} \cr
 #'  \code{bef.getProposal} \tab \code{\link{bef.portal.get.proposal}} \cr
-#'  \code{bef.searchTematres} \tab \code{\link{bef.tematres.search.keywords}} \cr
-#'  \code{bef.searchTematresLower} \tab \code{\link{bef.tematres.search.narrower_keywords}} \cr
-#'  \code{bef.searchTematresUpper} \tab \code{\link{bef.tematres.search.broader_keywords}} \cr
 #'  \code{bef.portal.get} \tab no replacement \cr
 #' }
 #'
 #' @name rbefdata-defunct
-#' @aliases bef.getDataset bef.getKeywords bef.getMetadata bef.getProposal bef.searchTematres bef.searchTematresLower bef.searchTematresUpper bef.portal.get
-#' @export bef.getDataset bef.getKeywords bef.getMetadata bef.getProposal bef.searchTematres bef.searchTematresLower bef.searchTematresUpper bef.portal.get
+#' @aliases bef.getDataset bef.getKeywords bef.getMetadata bef.getProposal bef.portal.get
+#' @export bef.getDataset bef.getKeywords bef.getMetadata bef.getProposal bef.portal.get
 #' @keywords internal
 #'
 
@@ -37,18 +34,6 @@ bef.getMetadata <- function(...) {
 bef.getProposal <- function(...) {
   .Defunct("bef.portal.get.proposal")
 }
-#' @rdname rbefdata-defunct
-bef.searchTematres <- function(...) {
-  .Defunct("bef.tematres.search.keywords")
-}
-#' @rdname rbefdata-defunct
-bef.searchTematresLower <- function(...) {
-  .Defunct("bef.tematres.search.narrower_keywords")
-}
-#' @rdname rbefdata-defunct
-bef.searchTematresUpper <- function(...) {
-  .Defunct("bef.tematres.search.broader_keywords")
-}
 
 # version 0.4 defuncts
 #' @rdname rbefdata-defunct
